## Info on typeshed's stubs for `Authlib`

### Upstream repo URL

[https://github.com/lepture/authlib](https://github.com/lepture/authlib)

### Stub distribution name

`types-Authlib`

### Number of lines

2,483 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 32 unique allowlist entries for `Authlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Authlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 246
    - Unannotated parameters: 1,119
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 5
- Returns:
    - Annotated returns: 455
    - Unannotated returns: 407
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 524
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 291
- Class definitions:
    - Total class definitions: 203
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Deprecated`

### Upstream repo URL

[https://github.com/tantale/deprecated](https://github.com/tantale/deprecated)

### Stub distribution name

`types-Deprecated`

### Number of lines

67 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Deprecated` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Deprecated`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 34
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ExifRead`

### Upstream repo URL

[https://github.com/ianare/exif-py](https://github.com/ianare/exif-py)

### Stub distribution name

`types-ExifRead`

### Number of lines

218 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `ExifRead` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ExifRead`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 72
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 52
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 82
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-Cors`

### Upstream repo URL

[https://github.com/corydolphin/flask-cors](https://github.com/corydolphin/flask-cors)

### Stub distribution name

`types-Flask-Cors`

### Number of lines

129 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Flask-Cors` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Cors`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 65
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 32
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-Migrate`

### Upstream repo URL

[https://github.com/miguelgrinberg/Flask-Migrate](https://github.com/miguelgrinberg/Flask-Migrate)

### Stub distribution name

`types-Flask-Migrate`

### Number of lines

128 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `Flask-Migrate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Migrate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-SocketIO`

### Upstream repo URL

[https://github.com/miguelgrinberg/flask-socketio](https://github.com/miguelgrinberg/flask-socketio)

### Stub distribution name

`types-Flask-SocketIO`

### Number of lines

249 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `Flask-SocketIO` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Flask-SocketIO`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 137
    - Unannotated parameters: 37
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 14
- Returns:
    - Annotated returns: 37
    - Unannotated returns: 15
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `JACK-Client`

### Upstream repo URL

[https://github.com/spatialaudio/jackclient-python](https://github.com/spatialaudio/jackclient-python)

### Stub distribution name

`types-JACK-Client`

### Number of lines

310 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 1 unique allowlist entry for `JACK-Client` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `JACK-Client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 107
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 152
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 46
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Jetson.GPIO`

### Upstream repo URL

[https://github.com/NVIDIA/jetson-gpio](https://github.com/NVIDIA/jetson-gpio)

### Stub distribution name

`types-Jetson.GPIO`

### Number of lines

173 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `Jetson.GPIO` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Jetson.GPIO`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 82
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 90
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Markdown`

### Upstream repo URL

[https://github.com/Python-Markdown/markdown](https://github.com/Python-Markdown/markdown)

### Stub distribution name

`types-Markdown`

### Number of lines

708 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `Markdown` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Markdown`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 257
    - Unannotated parameters: 30
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 199
    - Unannotated returns: 2
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 219
    - Explicit `Any` variables: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 102
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyAutoGUI`

### Upstream repo URL

[https://github.com/asweigart/pyautogui](https://github.com/asweigart/pyautogui)

### Stub distribution name

`types-PyAutoGUI`

### Number of lines

234 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `PyAutoGUI` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyAutoGUI`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 145
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 22
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyMySQL`

### Upstream repo URL

[https://github.com/PyMySQL/PyMySQL](https://github.com/PyMySQL/PyMySQL)

### Stub distribution name

`types-PyMySQL`

### Number of lines

1,107 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 10 unique allowlist entries for `PyMySQL` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `PyMySQL`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 136
    - Unannotated parameters: 79
    - Explicit `Any` parameters: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 127
    - Unannotated returns: 45
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 750
    - Explicit `Any` variables: 55
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 25
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyScreeze`

### Upstream repo URL

[https://github.com/asweigart/pyscreeze](https://github.com/asweigart/pyscreeze)

### Stub distribution name

`types-PyScreeze`

### Number of lines

193 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 2 unique allowlist entries for `PyScreeze` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyScreeze`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 102
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 21
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 17
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyYAML`

### Upstream repo URL

[https://github.com/yaml/pyyaml](https://github.com/yaml/pyyaml)

### Stub distribution name

`types-PyYAML`

### Number of lines

1,308 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `PyYAML` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `PyYAML`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 520
    - Unannotated parameters: 278
    - Explicit `Any` parameters: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 4
- Returns:
    - Annotated returns: 222
    - Unannotated returns: 172
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 160
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 91
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Pygments`

### Upstream repo URL

[https://github.com/pygments/pygments](https://github.com/pygments/pygments)

### Stub distribution name

`types-Pygments`

### Number of lines

837 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `Pygments` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Pygments`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 100
    - Unannotated parameters: 173
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 107
    - Unannotated returns: 77
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 376
    - Explicit `Any` variables: 169
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 24
- Class definitions:
    - Total class definitions: 94
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `RPi.GPIO`

### Upstream repo URL

[https://sourceforge.net/p/raspberry-gpio-python/code/](https://sourceforge.net/p/raspberry-gpio-python/code/)

### Stub distribution name

`types-RPi.GPIO`

### Number of lines

56 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `RPi.GPIO` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `RPi.GPIO`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Send2Trash`

### Upstream repo URL

[https://github.com/arsenetar/send2trash](https://github.com/arsenetar/send2trash)

### Stub distribution name

`types-Send2Trash`

### Number of lines

15 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `Send2Trash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Send2Trash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `TgCrypto`

### Upstream repo URL

[https://github.com/pyrogram/tgcrypto](https://github.com/pyrogram/tgcrypto)

### Stub distribution name

`types-TgCrypto`

### Number of lines

7 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `TgCrypto` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `TgCrypto`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `WTForms`

### Upstream repo URL

[https://github.com/pallets-eco/wtforms](https://github.com/pallets-eco/wtforms)

### Stub distribution name

`types-WTForms`

### Number of lines

1,343 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 21 unique allowlist entries for `WTForms` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `WTForms`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 531
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 71
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 185
    - Unannotated returns: 0
    - Explicit `Any` returns: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 141
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 100
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `WebOb`

### Upstream repo URL

[https://github.com/Pylons/webob](https://github.com/Pylons/webob)

### Stub distribution name

`types-WebOb`

### Number of lines

2,205 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 99 unique allowlist entries for `WebOb` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `WebOb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 793
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 80
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 606
    - Unannotated returns: 0
    - Explicit `Any` returns: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 250
    - Explicit `Any` variables: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 136
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `aiofiles`

### Upstream repo URL

[https://github.com/Tinche/aiofiles](https://github.com/Tinche/aiofiles)

### Stub distribution name

`types-aiofiles`

### Number of lines

733 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 86 unique allowlist entries for `aiofiles` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `aiofiles`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 405
    - Unannotated parameters: 27
    - Explicit `Any` parameters: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 148
    - Unannotated returns: 3
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `antlr4-python3-runtime`

### Upstream repo URL

[https://github.com/antlr/antlr4](https://github.com/antlr/antlr4)

### Stub distribution name

`types-antlr4-python3-runtime`

### Number of lines

1,777 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 0 allowlist entries for `antlr4-python3-runtime` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `antlr4-python3-runtime`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 768
    - Unannotated parameters: 231
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 18
- Returns:
    - Annotated returns: 208
    - Unannotated returns: 485
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 395
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 269
- Class definitions:
    - Total class definitions: 142
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `assertpy`

### Upstream repo URL

[https://github.com/assertpy/assertpy](https://github.com/assertpy/assertpy)

### Stub distribution name

`types-assertpy`

### Number of lines

214 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 unique allowlist entries for `assertpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `assertpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 85
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 87
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `atheris`

### Upstream repo URL

[https://github.com/google/atheris](https://github.com/google/atheris)

### Stub distribution name

`types-atheris`

### Number of lines

88 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `atheris` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `atheris`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `auth0-python`

### Upstream repo URL

[https://github.com/auth0/auth0-python](https://github.com/auth0/auth0-python)

### Stub distribution name

`types-auth0-python`

### Number of lines

1,647 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `auth0-python` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `auth0-python`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,117
    - Unannotated parameters: 14
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 141
- Returns:
    - Annotated returns: 366
    - Unannotated returns: 119
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 294
- Variables:
    - Annotated variables: 186
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 92
- Class definitions:
    - Total class definitions: 62
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `aws-xray-sdk`

### Upstream repo URL

[https://github.com/aws/aws-xray-sdk-python](https://github.com/aws/aws-xray-sdk-python)

### Stub distribution name

`types-aws-xray-sdk`

### Number of lines

655 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `aws-xray-sdk` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `aws-xray-sdk`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 118
    - Unannotated parameters: 175
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 182
    - Unannotated returns: 92
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 136
    - Explicit `Any` variables: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 45
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `beautifulsoup4`

### Upstream repo URL

[https://git.launchpad.net/beautifulsoup/tree](https://git.launchpad.net/beautifulsoup/tree)

### Stub distribution name

`types-beautifulsoup4`

### Number of lines

794 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `beautifulsoup4` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `beautifulsoup4`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 224
    - Unannotated parameters: 164
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 4
- Returns:
    - Annotated returns: 195
    - Unannotated returns: 49
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 177
    - Explicit `Any` variables: 70
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 47
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `binaryornot`

### Upstream repo URL

[https://github.com/binaryornot/binaryornot](https://github.com/binaryornot/binaryornot)

### Stub distribution name

`types-binaryornot`

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `binaryornot` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `binaryornot`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `bleach`

### Upstream repo URL

[https://github.com/mozilla/bleach](https://github.com/mozilla/bleach)

### Stub distribution name

`types-bleach`

### Number of lines

241 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `bleach` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `bleach`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 91
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 50
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 60
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `boltons`

### Upstream repo URL

[https://github.com/mahmoud/boltons](https://github.com/mahmoud/boltons)

### Stub distribution name

`types-boltons`

### Number of lines

1,350 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `boltons` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `boltons`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 608
    - Unannotated parameters: 335
    - Explicit `Any` parameters: 60
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 8
- Returns:
    - Annotated returns: 477
    - Unannotated returns: 170
    - Explicit `Any` returns: 16
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 233
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 68
- Class definitions:
    - Total class definitions: 83
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 3

---

## Info on typeshed's stubs for `braintree`

### Upstream repo URL

[https://github.com/braintree/braintree_python](https://github.com/braintree/braintree_python)

### Stub distribution name

`types-braintree`

### Number of lines

3,366 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `braintree` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `braintree`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 279
    - Unannotated parameters: 325
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 31
- Returns:
    - Annotated returns: 406
    - Unannotated returns: 135
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 14
- Variables:
    - Annotated variables: 1,486
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 114
- Class definitions:
    - Total class definitions: 290
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `cachetools`

### Upstream repo URL

[https://github.com/tkem/cachetools](https://github.com/tkem/cachetools)

### Stub distribution name

`types-cachetools`

### Number of lines

131 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 17 unique allowlist entries for `cachetools` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `cachetools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 94
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 49
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `capturer`

### Upstream repo URL

[https://github.com/xolox/python-capturer](https://github.com/xolox/python-capturer)

### Stub distribution name

`types-capturer`

### Number of lines

114 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `capturer` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `capturer`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 50
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `cffi`

### Upstream repo URL

[https://github.com/python-cffi/cffi/](https://github.com/python-cffi/cffi/)

### Stub distribution name

`types-cffi`

### Number of lines

840 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 4 unique allowlist entries for `cffi` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `cffi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 335
    - Unannotated parameters: 212
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 238
    - Unannotated returns: 86
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 252
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 75
- Class definitions:
    - Total class definitions: 52
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `chevron`

### Upstream repo URL

[https://github.com/noahmorrison/chevron](https://github.com/noahmorrison/chevron)

### Stub distribution name

`types-chevron`

### Number of lines

38 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `chevron` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `chevron`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 29
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-default-group`

### Upstream repo URL

[https://github.com/click-contrib/click-default-group](https://github.com/click-contrib/click-default-group)

### Stub distribution name

`types-click-default-group`

### Number of lines

79 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-default-group` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-default-group`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 52
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 14
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-log`

### Upstream repo URL

[https://github.com/click-contrib/click-log](https://github.com/click-contrib/click-log)

### Stub distribution name

`types-click-log`

### Number of lines

22 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-log` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-log`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-spinner`

### Upstream repo URL

[https://github.com/click-contrib/click-spinner](https://github.com/click-contrib/click-spinner)

### Stub distribution name

`types-click-spinner`

### Number of lines

36 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-spinner` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-spinner`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 11
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-web`

### Upstream repo URL

[https://github.com/fredrik-corneliusson/click-web](https://github.com/fredrik-corneliusson/click-web)

### Stub distribution name

`types-click-web`

### Number of lines

184 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-web` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `click-web`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 66
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 57
    - Unannotated returns: 3
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 53
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 28
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `colorama`

### Upstream repo URL

[https://github.com/tartley/colorama](https://github.com/tartley/colorama)

### Stub distribution name

`types-colorama`

### Number of lines

201 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 44 unique allowlist entries for `colorama` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `colorama`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 89
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 85
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `console-menu`

### Upstream repo URL

[https://github.com/aegirhall/console-menu](https://github.com/aegirhall/console-menu)

### Stub distribution name

`types-console-menu`

### Number of lines

736 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `console-menu` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `console-menu`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 217
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 278
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 58
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 39
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `croniter`

### Upstream repo URL

[https://github.com/pallets-eco/croniter](https://github.com/pallets-eco/croniter)

### Stub distribution name

`types-croniter`

### Number of lines

357 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `croniter` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `croniter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 164
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 48
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dateparser`

### Upstream repo URL

[https://github.com/scrapinghub/dateparser](https://github.com/scrapinghub/dateparser)

### Stub distribution name

`types-dateparser`

### Number of lines

500 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `dateparser` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `dateparser`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 159
    - Unannotated parameters: 104
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 108
    - Unannotated returns: 40
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 135
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 34
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `decorator`

### Upstream repo URL

[https://github.com/micheles/decorator](https://github.com/micheles/decorator)

### Stub distribution name

`types-decorator`

### Number of lines

67 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `decorator` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `decorator`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `defusedxml`

### Upstream repo URL

[https://github.com/tiran/defusedxml](https://github.com/tiran/defusedxml)

### Stub distribution name

`types-defusedxml`

### Number of lines

228 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `defusedxml` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `defusedxml`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 78
    - Unannotated parameters: 100
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 10
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 13
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 37
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 19
- Class definitions:
    - Total class definitions: 12
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dirhash`

### Upstream repo URL

[https://github.com/andhus/dirhash-python](https://github.com/andhus/dirhash-python)

### Stub distribution name

`types-dirhash`

### Number of lines

88 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `dirhash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `dirhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 39
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `django-import-export`

### Upstream repo URL

[https://github.com/django-import-export/django-import-export](https://github.com/django-import-export/django-import-export)

### Stub distribution name

`types-django-import-export`

### Number of lines

687 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `django-import-export` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `django-import-export`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 367
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 128
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 250
    - Unannotated returns: 0
    - Explicit `Any` returns: 35
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 154
    - Explicit `Any` variables: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 70
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `docker`

### Upstream repo URL

[https://github.com/docker/docker-py](https://github.com/docker/docker-py)

### Stub distribution name

`types-docker`

### Number of lines

2,403 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 unique allowlist entries for `docker` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `docker`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,135
    - Unannotated parameters: 354
    - Explicit `Any` parameters: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 63
- Returns:
    - Annotated returns: 376
    - Unannotated returns: 196
    - Explicit `Any` returns: 24
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 15
- Variables:
    - Annotated variables: 221
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 59
- Class definitions:
    - Total class definitions: 136
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 24

---

## Info on typeshed's stubs for `dockerfile-parse`

### Upstream repo URL

[https://github.com/containerbuildsystem/dockerfile-parse](https://github.com/containerbuildsystem/dockerfile-parse)

### Stub distribution name

`types-dockerfile-parse`

### Number of lines

113 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `dockerfile-parse` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `dockerfile-parse`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 39
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `docutils`

### Upstream repo URL

[https://sourceforge.net/p/docutils/code](https://sourceforge.net/p/docutils/code)

### Stub distribution name

`types-docutils`

### Number of lines

3,073 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 unique allowlist entries for `docutils` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `docutils`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,091
    - Unannotated parameters: 534
    - Explicit `Any` parameters: 39
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 862
    - Unannotated returns: 207
    - Explicit `Any` returns: 217
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 824
    - Explicit `Any` variables: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 125
- Class definitions:
    - Total class definitions: 365
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `editdistance`

### Upstream repo URL

[https://github.com/roy-ht/editdistance](https://github.com/roy-ht/editdistance)

### Stub distribution name

`types-editdistance`

### Number of lines

6 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `editdistance` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `editdistance`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `entrypoints`

### Upstream repo URL

[https://github.com/takluyver/entrypoints](https://github.com/takluyver/entrypoints)

### Stub distribution name

`types-entrypoints`

### Number of lines

41 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `entrypoints` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `entrypoints`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 23
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `fanstatic`

### Upstream repo URL

[https://github.com/zopefoundation/fanstatic](https://github.com/zopefoundation/fanstatic)

### Stub distribution name

`types-fanstatic`

### Number of lines

534 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 40 unique allowlist entries for `fanstatic` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `fanstatic`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 167
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 134
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 128
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 50
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `first`

### Upstream repo URL

[https://github.com/hynek/first](https://github.com/hynek/first)

### Stub distribution name

`types-first`

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `first` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `first`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 11
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8`

### Upstream repo URL

[https://github.com/pycqa/flake8](https://github.com/pycqa/flake8)

### Stub distribution name

`types-flake8`

### Number of lines

570 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `flake8` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 222
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 35
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 164
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 182
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 90
- Class definitions:
    - Total class definitions: 39
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-bugbear`

### Upstream repo URL

[https://github.com/PyCQA/flake8-bugbear](https://github.com/PyCQA/flake8-bugbear)

### Stub distribution name

`types-flake8-bugbear`

### Number of lines

277 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 35 unique allowlist entries for `flake8-bugbear` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-bugbear`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 130
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 119
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 99
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-builtins`

### Upstream repo URL

[https://github.com/gforcada/flake8-builtins](https://github.com/gforcada/flake8-builtins)

### Stub distribution name

`types-flake8-builtins`

### Number of lines

38 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-builtins` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-builtins`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 15
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 11
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-docstrings`

### Upstream repo URL

[https://github.com/pycqa/flake8-docstrings](https://github.com/pycqa/flake8-docstrings)

### Stub distribution name

`types-flake8-docstrings`

### Number of lines

21 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-docstrings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-rst-docstrings`

### Upstream repo URL

[https://github.com/peterjc/flake8-rst-docstrings](https://github.com/peterjc/flake8-rst-docstrings)

### Stub distribution name

`types-flake8-rst-docstrings`

### Number of lines

31 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-rst-docstrings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-rst-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-simplify`

### Upstream repo URL

[https://github.com/MartinThoma/flake8-simplify](https://github.com/MartinThoma/flake8-simplify)

### Stub distribution name

`types-flake8-simplify`

### Number of lines

8 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-simplify` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-simplify`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-typing-imports`

### Upstream repo URL

[https://github.com/asottile/flake8-typing-imports](https://github.com/asottile/flake8-typing-imports)

### Stub distribution name

`types-flake8-typing-imports`

### Number of lines

14 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-typing-imports` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `flake8-typing-imports`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 1
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `fpdf2`

### Upstream repo URL

[https://github.com/PyFPDF/fpdf2](https://github.com/PyFPDF/fpdf2)

### Stub distribution name

`types-fpdf2`

### Number of lines

3,622 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `fpdf2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `fpdf2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,054
    - Unannotated parameters: 703
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 13
- Returns:
    - Annotated returns: 660
    - Unannotated returns: 196
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 772
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 173
- Class definitions:
    - Total class definitions: 224
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `gdb`

### Extra description

Type hints for GDB's [Python API](https://sourceware.org/gdb/onlinedocs/gdb/Python-API.html). Note that this API is available only when running Python scripts under GDB: it is not possible to install the `gdb` package separately, for instance using `pip`.

### Upstream repo URL

[https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;a=tree](https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;a=tree)

### Stub distribution name

`types-gdb`

### Number of lines

1,096 (excluding blank lines)

### Package status: *not on pypi*

The runtime package that these stubs are for doesn't exist on PyPI, so whether or not these stubs are up to date or not is unknown.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 47 unique allowlist entries for `gdb` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `gdb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 322
    - Unannotated parameters: 26
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 315
    - Unannotated returns: 39
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 373
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 17
- Class definitions:
    - Total class definitions: 107
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `geopandas`

### Upstream repo URL

[https://github.com/geopandas/geopandas](https://github.com/geopandas/geopandas)

### Stub distribution name

`types-geopandas`

### Number of lines

1,787 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 15 unique allowlist entries for `geopandas` when running stubtest in CI.

### Pyright settings in CI: *entirely excluded*

All files in this stubs package are excluded from the pyright check in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `geopandas`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,002
    - Unannotated parameters: 68
    - Explicit `Any` parameters: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 38
- Returns:
    - Annotated returns: 402
    - Unannotated returns: 7
    - Explicit `Any` returns: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 30
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 19
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `gevent`

### Upstream repo URL

[https://github.com/gevent/gevent](https://github.com/gevent/gevent)

### Stub distribution name

`types-gevent`

### Number of lines

3,165 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 144 unique allowlist entries for `gevent` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `gevent`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,366
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 68
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 839
    - Unannotated returns: 0
    - Explicit `Any` returns: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 371
    - Explicit `Any` variables: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 211
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `google-cloud-ndb`

### Upstream repo URL

[https://github.com/googleapis/python-ndb](https://github.com/googleapis/python-ndb)

### Stub distribution name

`types-google-cloud-ndb`

### Number of lines

1,536 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `google-cloud-ndb` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `google-cloud-ndb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 486
    - Unannotated parameters: 368
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 123
- Returns:
    - Annotated returns: 236
    - Unannotated returns: 203
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 194
    - Explicit `Any` variables: 132
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 143
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `greenlet`

### Upstream repo URL

[https://github.com/python-greenlet/greenlet](https://github.com/python-greenlet/greenlet)

### Stub distribution name

`types-greenlet`

### Number of lines

84 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `greenlet` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `greenlet`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 21
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio`

### Number of lines

929 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `grpcio` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 315
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 211
    - Unannotated returns: 1
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 29
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 73
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-channelz`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-channelz`

### Number of lines

724 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-channelz` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-channelz`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 156
    - Unannotated parameters: 94
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 54
- Returns:
    - Annotated returns: 55
    - Unannotated returns: 15
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 324
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 21
- Class definitions:
    - Total class definitions: 44
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-health-checking`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-health-checking`

### Number of lines

89 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-health-checking` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-health-checking`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 27
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 6
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-reflection`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-reflection`

### Number of lines

165 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-reflection` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-reflection`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 34
    - Unannotated parameters: 17
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 55
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-status`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-status`

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-status` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-status`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 1
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hdbcli`

### Stub distribution name

`types-hdbcli`

### Number of lines

140 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 8 unique allowlist entries for `hdbcli` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `hdbcli`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 78
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 65
    - Unannotated returns: 3
    - Explicit `Any` returns: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hnswlib`

### Upstream repo URL

[https://github.com/nmslib/hnswlib](https://github.com/nmslib/hnswlib)

### Stub distribution name

`types-hnswlib`

### Number of lines

60 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `hnswlib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `hnswlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `html5lib`

### Upstream repo URL

[https://github.com/html5lib/html5lib-python](https://github.com/html5lib/html5lib-python)

### Stub distribution name

`types-html5lib`

### Number of lines

685 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `html5lib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `html5lib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 64
    - Unannotated parameters: 218
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 133
    - Unannotated returns: 177
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 224
    - Explicit `Any` variables: 175
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 41
    - Class definitions with `Any`: 4
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `httplib2`

### Upstream repo URL

[https://github.com/httplib2/httplib2](https://github.com/httplib2/httplib2)

### Stub distribution name

`types-httplib2`

### Number of lines

234 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `httplib2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `httplib2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 9
    - Unannotated parameters: 159
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 25
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 87
    - Explicit `Any` variables: 58
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 33
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hvac`

### Upstream repo URL

[https://github.com/hvac/hvac](https://github.com/hvac/hvac)

### Stub distribution name

`types-hvac`

### Number of lines

1,824 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `hvac` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `hvac`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 510
    - Unannotated parameters: 1,222
    - Explicit `Any` parameters: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 491
    - Explicit `Any` returns: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 94
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 15
- Class definitions:
    - Total class definitions: 75
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ibm-db`

### Upstream repo URL

[https://github.com/ibmdb/python-ibmdb](https://github.com/ibmdb/python-ibmdb)

### Stub distribution name

`types-ibm-db`

### Number of lines

346 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ibm-db` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ibm-db`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 168
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 202
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `icalendar`

### Upstream repo URL

[https://github.com/collective/icalendar](https://github.com/collective/icalendar)

### Stub distribution name

`types-icalendar`

### Number of lines

1,334 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 14 unique allowlist entries for `icalendar` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `icalendar`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 354
    - Unannotated parameters: 21
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 418
    - Unannotated returns: 8
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 152
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 65
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `inifile`

### Upstream repo URL

[https://github.com/mitsuhiko/python-inifile](https://github.com/mitsuhiko/python-inifile)

### Stub distribution name

`types-inifile`

### Number of lines

122 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 unique allowlist entries for `inifile` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `inifile`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 57
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 58
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jmespath`

### Upstream repo URL

[https://github.com/jmespath/jmespath.py](https://github.com/jmespath/jmespath.py)

### Stub distribution name

`types-jmespath`

### Number of lines

207 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `jmespath` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jmespath`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 122
    - Unannotated parameters: 11
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 74
    - Unannotated returns: 0
    - Explicit `Any` returns: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 49
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 23
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jsonschema`

### Upstream repo URL

[https://github.com/python-jsonschema/jsonschema](https://github.com/python-jsonschema/jsonschema)

### Stub distribution name

`types-jsonschema`

### Number of lines

427 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `jsonschema` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jsonschema`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 116
    - Unannotated parameters: 310
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 8
- Returns:
    - Annotated returns: 159
    - Unannotated returns: 25
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 13
- Variables:
    - Annotated variables: 52
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 16
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jwcrypto`

### Upstream repo URL

[https://github.com/latchset/jwcrypto](https://github.com/latchset/jwcrypto)

### Stub distribution name

`types-jwcrypto`

### Number of lines

472 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `jwcrypto` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jwcrypto`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 151
    - Unannotated parameters: 31
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 133
    - Unannotated returns: 8
    - Explicit `Any` returns: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 55
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 40
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `keyboard`

### Upstream repo URL

[https://github.com/boppreh/keyboard](https://github.com/boppreh/keyboard)

### Stub distribution name

`types-keyboard`

### Number of lines

246 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 unique allowlist entries for `keyboard` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `keyboard`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 130
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 76
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ldap3`

### Upstream repo URL

[https://github.com/cannatag/ldap3](https://github.com/cannatag/ldap3)

### Stub distribution name

`types-ldap3`

### Number of lines

2,484 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ldap3` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `ldap3`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 276
    - Unannotated parameters: 936
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 219
    - Unannotated returns: 421
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 931
    - Explicit `Any` variables: 322
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 57
- Class definitions:
    - Total class definitions: 316
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `libsass`

### Upstream repo URL

[https://github.com/sass/libsass-python](https://github.com/sass/libsass-python)

### Stub distribution name

`types-libsass`

### Number of lines

250 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `libsass` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `libsass`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 36
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 17
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `lupa`

### Upstream repo URL

[https://github.com/scoder/lupa](https://github.com/scoder/lupa)

### Stub distribution name

`types-lupa`

### Number of lines

480 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `lupa` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `lupa`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 150
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 126
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 61
    - Explicit `Any` variables: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 54
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `lzstring`

### Upstream repo URL

[https://github.com/gkovacs/lz-string-python](https://github.com/gkovacs/lz-string-python)

### Stub distribution name

`types-lzstring`

### Number of lines

17 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `lzstring` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `lzstring`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `m3u8`

### Upstream repo URL

[https://github.com/globocom/m3u8](https://github.com/globocom/m3u8)

### Stub distribution name

`types-m3u8`

### Number of lines

549 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 15 unique allowlist entries for `m3u8` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `m3u8`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 147
    - Unannotated parameters: 23
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 85
    - Unannotated returns: 1
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 214
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 12
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mock`

### Upstream repo URL

[https://github.com/testing-cabal/mock](https://github.com/testing-cabal/mock)

### Stub distribution name

`types-mock`

### Number of lines

367 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `mock` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `mock`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 196
    - Unannotated parameters: 20
    - Explicit `Any` parameters: 86
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 25
- Returns:
    - Annotated returns: 90
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 58
    - Explicit `Any` variables: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mypy-extensions`

### Upstream repo URL

[https://github.com/python/mypy_extensions](https://github.com/python/mypy_extensions)

### Stub distribution name

`types-mypy-extensions`

### Number of lines

80 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `mypy-extensions` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `mypy-extensions`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 31
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 28
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mysqlclient`

### Upstream repo URL

[https://github.com/PyMySQL/mysqlclient](https://github.com/PyMySQL/mysqlclient)

### Stub distribution name

`types-mysqlclient`

### Number of lines

1,272 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `mysqlclient` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `mysqlclient`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 67
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 40
    - Unannotated returns: 76
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 971
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 28
- Class definitions:
    - Total class definitions: 35
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `nanoid`

### Upstream repo URL

[https://github.com/puyuan/py-nanoid](https://github.com/puyuan/py-nanoid)

### Stub distribution name

`types-nanoid`

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `nanoid` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `nanoid`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `nanoleafapi`

### Upstream repo URL

[https://github.com/MylesMor/nanoleafapi](https://github.com/MylesMor/nanoleafapi)

### Stub distribution name

`types-nanoleafapi`

### Number of lines

91 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `nanoleafapi` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `nanoleafapi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 33
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 49
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `netaddr`

### Upstream repo URL

[https://github.com/drkjam/netaddr](https://github.com/drkjam/netaddr)

### Stub distribution name

`types-netaddr`

### Number of lines

698 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `netaddr` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `netaddr`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 288
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 308
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 101
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 43
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `netifaces`

### Upstream repo URL

[https://github.com/al45tair/netifaces](https://github.com/al45tair/netifaces)

### Stub distribution name

`types-netifaces`

### Number of lines

69 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 33 unique allowlist entries for `netifaces` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `netifaces`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 65
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `networkx`

### Upstream repo URL

[https://github.com/networkx/networkx](https://github.com/networkx/networkx)

### Stub distribution name

`types-networkx`

### Number of lines

6,711 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 24 unique allowlist entries for `networkx` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `networkx`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,618
    - Unannotated parameters: 1,583
    - Explicit `Any` parameters: 35
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 246
- Returns:
    - Annotated returns: 744
    - Unannotated returns: 834
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 168
- Variables:
    - Annotated variables: 343
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 243
- Class definitions:
    - Total class definitions: 130
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `oauthlib`

### Upstream repo URL

[https://github.com/oauthlib/oauthlib](https://github.com/oauthlib/oauthlib)

### Stub distribution name

`types-oauthlib`

### Number of lines

1,787 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `oauthlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `oauthlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 724
    - Unannotated parameters: 214
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 28
- Returns:
    - Annotated returns: 300
    - Unannotated returns: 61
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 11
- Variables:
    - Annotated variables: 333
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 12
- Class definitions:
    - Total class definitions: 110
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `objgraph`

### Upstream repo URL

[https://github.com/mgedmin/objgraph](https://github.com/mgedmin/objgraph)

### Stub distribution name

`types-objgraph`

### Number of lines

87 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `objgraph` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `objgraph`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `olefile`

### Upstream repo URL

[https://github.com/decalage2/olefile](https://github.com/decalage2/olefile)

### Stub distribution name

`types-olefile`

### Number of lines

222 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `olefile` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `olefile`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 103
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 66
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 75
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `openpyxl`

### Upstream repo URL

[https://foss.heptapod.net/openpyxl/openpyxl](https://foss.heptapod.net/openpyxl/openpyxl)

### Stub distribution name

`types-openpyxl`

### Number of lines

13,146 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 181 unique allowlist entries for `openpyxl` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `openpyxl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,708
    - Unannotated parameters: 510
    - Explicit `Any` parameters: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 13
- Returns:
    - Annotated returns: 1,314
    - Unannotated returns: 87
    - Explicit `Any` returns: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 4,019
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 339
- Class definitions:
    - Total class definitions: 603
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 20

---

## Info on typeshed's stubs for `opentracing`

### Upstream repo URL

[https://github.com/opentracing/opentracing-python](https://github.com/opentracing/opentracing-python)

### Stub distribution name

`types-opentracing`

### Number of lines

330 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `opentracing` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `opentracing`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 104
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 56
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `paramiko`

### Upstream repo URL

[https://github.com/paramiko/paramiko](https://github.com/paramiko/paramiko)

### Stub distribution name

`types-paramiko`

### Number of lines

1,845 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 6 unique allowlist entries for `paramiko` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `paramiko`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 773
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 642
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 545
    - Explicit `Any` variables: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 124
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `parsimonious`

### Upstream repo URL

[https://github.com/erikrose/parsimonious](https://github.com/erikrose/parsimonious)

### Stub distribution name

`types-parsimonious`

### Number of lines

187 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `parsimonious` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `parsimonious`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 114
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 59
    - Unannotated returns: 1
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 27
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `passlib`

### Upstream repo URL

[https://foss.heptapod.net/python-libs/passlib](https://foss.heptapod.net/python-libs/passlib)

### Stub distribution name

`types-passlib`

### Number of lines

2,037 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 35 unique allowlist entries for `passlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `passlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 470
    - Unannotated parameters: 453
    - Explicit `Any` parameters: 32
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 267
    - Unannotated returns: 231
    - Explicit `Any` returns: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 579
    - Explicit `Any` variables: 59
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 143
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `passpy`

### Upstream repo URL

[https://github.com/bfrascher/passpy](https://github.com/bfrascher/passpy)

### Stub distribution name

`types-passpy`

### Number of lines

47 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `passpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `passpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `peewee`

### Upstream repo URL

[https://github.com/coleifer/peewee](https://github.com/coleifer/peewee)

### Stub distribution name

`types-peewee`

### Number of lines

1,778 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 unique allowlist entries for `peewee` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `peewee`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 416
    - Unannotated parameters: 681
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 202
- Returns:
    - Annotated returns: 363
    - Unannotated returns: 423
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 423
    - Explicit `Any` variables: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 319
- Class definitions:
    - Total class definitions: 169
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pep8-naming`

### Upstream repo URL

[https://github.com/PyCQA/pep8-naming](https://github.com/PyCQA/pep8-naming)

### Stub distribution name

`types-pep8-naming`

### Number of lines

150 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pep8-naming` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pep8-naming`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 92
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 33
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pexpect`

### Upstream repo URL

[https://github.com/pexpect/pexpect](https://github.com/pexpect/pexpect)

### Stub distribution name

`types-pexpect`

### Number of lines

669 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `pexpect` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pexpect`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 226
    - Unannotated parameters: 128
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 181
    - Unannotated returns: 33
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 160
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 24
- Class definitions:
    - Total class definitions: 22
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pika`

### Extra description

The `types-pika` package contains alternate, more complete type stubs, that are maintained outside of typeshed.

### Upstream repo URL

[https://github.com/pika/pika](https://github.com/pika/pika)

### Stub distribution name

`types-pika-ts`

### Number of lines

2,185 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 unique allowlist entries for `pika` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pika`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 640
    - Unannotated parameters: 365
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 42
- Returns:
    - Annotated returns: 623
    - Unannotated returns: 142
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 24
- Variables:
    - Annotated variables: 468
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 148
- Class definitions:
    - Total class definitions: 223
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `polib`

### Upstream repo URL

[https://github.com/izimobil/polib](https://github.com/izimobil/polib)

### Stub distribution name

`types-polib`

### Number of lines

158 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `polib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `polib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 61
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `portpicker`

### Upstream repo URL

[https://github.com/google/python_portpicker](https://github.com/google/python_portpicker)

### Stub distribution name

`types-portpicker`

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `portpicker` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `portpicker`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `protobuf`

### Extra description

Partially generated using [mypy-protobuf==3.6.0](https://github.com/nipunn1313/mypy-protobuf/tree/v3.6.0) and libprotoc 29.0 on [protobuf v30.2](https://github.com/protocolbuffers/protobuf/releases/tag/v30.2) (python `protobuf==6.30.2`).

### Upstream repo URL

[https://github.com/protocolbuffers/protobuf](https://github.com/protocolbuffers/protobuf)

### Stub distribution name

`types-protobuf`

### Number of lines

6,003 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 10 unique allowlist entries for `protobuf` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `protobuf`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 800
    - Unannotated parameters: 376
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 579
    - Unannotated returns: 157
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1,074
    - Explicit `Any` variables: 122
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 88
- Class definitions:
    - Total class definitions: 208
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `psutil`

### Upstream repo URL

[https://github.com/giampaolo/psutil](https://github.com/giampaolo/psutil)

### Stub distribution name

`types-psutil`

### Number of lines

1,629 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 12 unique allowlist entries for `psutil` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `psutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 114
    - Unannotated parameters: 325
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 10
- Returns:
    - Annotated returns: 201
    - Unannotated returns: 350
    - Explicit `Any` returns: 47
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 597
    - Explicit `Any` variables: 177
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 95
- Class definitions:
    - Total class definitions: 90
    - Class definitions with `Any`: 3
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `psycopg2`

### Upstream repo URL

[https://github.com/psycopg/psycopg2](https://github.com/psycopg/psycopg2)

### Stub distribution name

`types-psycopg2`

### Number of lines

1,731 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `psycopg2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `psycopg2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 309
    - Unannotated parameters: 178
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 315
    - Unannotated returns: 74
    - Explicit `Any` returns: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 518
    - Explicit `Any` variables: 60
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 332
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyRFC3339`

### Upstream repo URL

[https://github.com/kurtraschke/pyRFC3339](https://github.com/kurtraschke/pyRFC3339)

### Stub distribution name

`types-pyRFC3339`

### Number of lines

8 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyRFC3339` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyRFC3339`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyasn1`

### Upstream repo URL

[https://github.com/pyasn1/pyasn1](https://github.com/pyasn1/pyasn1)

### Stub distribution name

`types-pyasn1`

### Number of lines

1,484 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `pyasn1` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pyasn1`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 197
    - Unannotated parameters: 535
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 33
- Returns:
    - Annotated returns: 112
    - Unannotated returns: 422
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 9
- Variables:
    - Annotated variables: 248
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 178
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyaudio`

### Stub distribution name

`types-pyaudio`

### Number of lines

165 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 0 allowlist entries for `pyaudio` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyaudio`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 37
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 72
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pycocotools`

### Upstream repo URL

[https://github.com/ppwwyyxx/cocoapi](https://github.com/ppwwyyxx/cocoapi)

### Stub distribution name

`types-pycocotools`

### Number of lines

162 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pycocotools` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pycocotools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 70
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 12
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pycurl`

### Upstream repo URL

[https://github.com/pycurl/pycurl](https://github.com/pycurl/pycurl)

### Stub distribution name

`types-pycurl`

### Number of lines

725 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 0 allowlist entries for `pycurl` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pycurl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 7
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 6
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 679
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyfarmhash`

### Upstream repo URL

[https://github.com/veelion/python-farmhash](https://github.com/veelion/python-farmhash)

### Stub distribution name

`types-pyfarmhash`

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyfarmhash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyfarmhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyflakes`

### Upstream repo URL

[https://github.com/PyCQA/pyflakes](https://github.com/PyCQA/pyflakes)

### Stub distribution name

`types-pyflakes`

### Number of lines

464 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 27 unique allowlist entries for `pyflakes` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyflakes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 341
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 214
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 77
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 76
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyinstaller`

### Upstream repo URL

[https://github.com/pyinstaller/pyinstaller](https://github.com/pyinstaller/pyinstaller)

### Stub distribution name

`types-pyinstaller`

### Number of lines

759 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 49 unique allowlist entries for `pyinstaller` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyinstaller`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 305
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 167
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 225
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 31
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyjks`

### Upstream repo URL

[https://github.com/kurtbrose/pyjks](https://github.com/kurtbrose/pyjks)

### Stub distribution name

`types-pyjks`

### Number of lines

377 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 38 unique allowlist entries for `pyjks` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyjks`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 132
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 59
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 73
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 31
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pynput`

### Upstream repo URL

[https://github.com/moses-palmer/pynput](https://github.com/moses-palmer/pynput)

### Stub distribution name

`types-pynput`

### Number of lines

332 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 12 unique allowlist entries for `pynput` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pynput`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 87
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 71
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 63
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyperclip`

### Upstream repo URL

[https://github.com/asweigart/pyperclip](https://github.com/asweigart/pyperclip)

### Stub distribution name

`types-pyperclip`

### Number of lines

18 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 1 unique allowlist entry for `pyperclip` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyperclip`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyserial`

### Upstream repo URL

[https://github.com/pyserial/pyserial](https://github.com/pyserial/pyserial)

### Stub distribution name

`types-pyserial`

### Number of lines

1,171 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 64 unique allowlist entries for `pyserial` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyserial`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 224
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 271
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 466
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 65
- Class definitions:
    - Total class definitions: 68
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pysftp`

### Upstream repo URL

[https://bitbucket.org/dundeemt/pysftp](https://bitbucket.org/dundeemt/pysftp)

### Stub distribution name

`types-pysftp`

### Number of lines

166 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pysftp` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pysftp`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pytest-lazy-fixture`

### Upstream repo URL

[https://github.com/tvorog/pytest-lazy-fixture](https://github.com/tvorog/pytest-lazy-fixture)

### Stub distribution name

`types-pytest-lazy-fixture`

### Number of lines

12 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 8 unique allowlist entries for `pytest-lazy-fixture` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pytest-lazy-fixture`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-crontab`

### Upstream repo URL

[https://gitlab.com/doctormo/python-crontab](https://gitlab.com/doctormo/python-crontab)

### Stub distribution name

`types-python-crontab`

### Number of lines

329 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `python-crontab` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-crontab`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 176
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 147
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 72
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 18
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `python-datemath`

### Upstream repo URL

[https://github.com/nickmaccarthy/python-datemath](https://github.com/nickmaccarthy/python-datemath)

### Stub distribution name

`types-python-datemath`

### Number of lines

15 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `python-datemath` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-datemath`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 1
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-dateutil`

### Upstream repo URL

[https://github.com/dateutil/dateutil](https://github.com/dateutil/dateutil)

### Stub distribution name

`types-python-dateutil`

### Number of lines

427 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 unique allowlist entries for `python-dateutil` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-dateutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 164
    - Unannotated parameters: 70
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 109
    - Unannotated returns: 42
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 89
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 4
- Class definitions:
    - Total class definitions: 30
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-http-client`

### Upstream repo URL

[https://github.com/sendgrid/python-http-client](https://github.com/sendgrid/python-http-client)

### Stub distribution name

`types-python-http-client`

### Number of lines

71 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `python-http-client` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-http-client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 3
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-jenkins`

### Upstream repo URL

[https://opendev.org/jjb/python-jenkins](https://opendev.org/jjb/python-jenkins)

### Stub distribution name

`types-python-jenkins`

### Number of lines

248 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `python-jenkins` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-jenkins`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 195
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 101
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 73
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-jose`

### Upstream repo URL

[https://github.com/mpdavis/python-jose](https://github.com/mpdavis/python-jose)

### Stub distribution name

`types-python-jose`

### Number of lines

359 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `python-jose` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-jose`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 83
    - Unannotated parameters: 43
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 65
    - Unannotated returns: 26
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 119
    - Explicit `Any` variables: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-nmap`

### Upstream repo URL

[https://bitbucket.org/xael/python-nmap](https://bitbucket.org/xael/python-nmap)

### Stub distribution name

`types-python-nmap`

### Number of lines

119 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `python-nmap` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-nmap`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 44
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 31
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-xlib`

### Upstream repo URL

[https://github.com/python-xlib/python-xlib](https://github.com/python-xlib/python-xlib)

### Stub distribution name

`types-python-xlib`

### Number of lines

5,421 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 10 unique allowlist entries for `python-xlib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-xlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,334
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 583
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3,519
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 425
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pytz`

### Upstream repo URL

[https://github.com/stub42/pytz](https://github.com/stub42/pytz)

### Stub distribution name

`types-pytz`

### Number of lines

150 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `pytz` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `pytz`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 69
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 51
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 30
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pywin32`

### Upstream repo URL

[https://github.com/mhammond/pywin32](https://github.com/mhammond/pywin32)

### Stub distribution name

`types-pywin32`

### Number of lines

39,269 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `win32` only.

Typeshed currently has 40 unique allowlist entries for `pywin32` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pywin32`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,832
    - Unannotated parameters: 3,645
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 413
- Returns:
    - Annotated returns: 3,982
    - Unannotated returns: 1,971
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 284
- Variables:
    - Annotated variables: 29,459
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2,857
- Class definitions:
    - Total class definitions: 744
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyxdg`

### Upstream repo URL

[https://github.com/takluyver/pyxdg](https://github.com/takluyver/pyxdg)

### Stub distribution name

`types-pyxdg`

### Number of lines

860 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `pyxdg` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pyxdg`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 511
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 297
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 165
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 31
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `qrbill`

### Upstream repo URL

[https://github.com/claudep/swiss-qr-bill](https://github.com/claudep/swiss-qr-bill)

### Stub distribution name

`types-qrbill`

### Number of lines

172 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `qrbill` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `qrbill`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 96
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 31
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 33
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `qrcode`

### Upstream repo URL

[https://github.com/lincolnloop/python-qrcode](https://github.com/lincolnloop/python-qrcode)

### Stub distribution name

`types-qrcode`

### Number of lines

651 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 unique allowlist entries for `qrcode` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `qrcode`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 282
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 152
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 151
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ratelimit`

### Upstream repo URL

[https://github.com/tomasbasham/ratelimit](https://github.com/tomasbasham/ratelimit)

### Stub distribution name

`types-ratelimit`

### Number of lines

19 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `ratelimit` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ratelimit`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `regex`

### Upstream repo URL

[https://github.com/mrabarnett/mrab-regex](https://github.com/mrabarnett/mrab-regex)

### Stub distribution name

`types-regex`

### Number of lines

746 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 16 unique allowlist entries for `regex` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `regex`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 433
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 114
    - Unannotated returns: 0
    - Explicit `Any` returns: 16
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `reportlab`

### Upstream repo URL

[https://github.com/MrBitBucket/reportlab-mirror](https://github.com/MrBitBucket/reportlab-mirror)

### Stub distribution name

`types-reportlab`

### Number of lines

7,924 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 71 unique allowlist entries for `reportlab` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `reportlab`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,780
    - Unannotated parameters: 2,578
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 10
- Returns:
    - Annotated returns: 1,586
    - Unannotated returns: 979
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 2,759
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1,177
- Class definitions:
    - Total class definitions: 582
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 3

---

## Info on typeshed's stubs for `requests`

### Extra description

Note: `types-requests` has required `urllib3>=2` since v2.31.0.7. If you need to install `types-requests` into an environment that must also have `urllib3<2` installed into it, you will have to use `types-requests<2.31.0.7`.

### Upstream repo URL

[https://github.com/psf/requests](https://github.com/psf/requests)

### Stub distribution name

`types-requests`

### Number of lines

1,033 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `requests` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `requests`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 382
    - Unannotated parameters: 132
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 135
    - Unannotated returns: 65
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 125
    - Explicit `Any` variables: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 20
- Class definitions:
    - Total class definitions: 53
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `requests-oauthlib`

### Upstream repo URL

[https://github.com/requests/requests-oauthlib](https://github.com/requests/requests-oauthlib)

### Stub distribution name

`types-requests-oauthlib`

### Number of lines

267 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `requests-oauthlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `requests-oauthlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 68
    - Unannotated parameters: 69
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 45
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 25
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 7
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `retry`

### Upstream repo URL

[https://github.com/invl/retry](https://github.com/invl/retry)

### Stub distribution name

`types-retry`

### Number of lines

29 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `retry` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `retry`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `rfc3339-validator`

### Upstream repo URL

[https://github.com/naimetti/rfc3339-validator](https://github.com/naimetti/rfc3339-validator)

### Stub distribution name

`types-rfc3339-validator`

### Number of lines

8 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `rfc3339-validator` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `rfc3339-validator`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 1
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `s2clientprotocol`

### Extra description

Partially generated using [mypy-protobuf==3.6.0](https://github.com/nipunn1313/mypy-protobuf/tree/v3.6.0) and libprotoc 27.2 on [s2client-proto 5.0.12.91115.0](https://github.com/Blizzard/s2client-proto/tree/c04df4adbe274858a4eb8417175ee32ad02fd609).

### Upstream repo URL

[https://github.com/Blizzard/s2client-proto](https://github.com/Blizzard/s2client-proto)

### Stub distribution name

`types-s2clientprotocol`

### Number of lines

6,947 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `s2clientprotocol` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `s2clientprotocol`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 856
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 676
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1,864
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 239
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `seaborn`

### Upstream repo URL

[https://github.com/mwaskom/seaborn](https://github.com/mwaskom/seaborn)

### Stub distribution name

`types-seaborn`

### Number of lines

2,587 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `seaborn` when running stubtest in CI.

### Pyright settings in CI: *entirely excluded*

All files in this stubs package are excluded from the pyright check in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `seaborn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,447
    - Unannotated parameters: 29
    - Explicit `Any` parameters: 156
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 30
- Returns:
    - Annotated returns: 358
    - Unannotated returns: 2
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 282
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 24
- Class definitions:
    - Total class definitions: 100
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `setuptools`

### Extra description

Given that `pkg_resources` is typed since `setuptools >= 71.1`, it is no longer included with `types-setuptools`.

### Upstream repo URL

[https://github.com/pypa/setuptools](https://github.com/pypa/setuptools)

### Stub distribution name

`types-setuptools`

### Number of lines

2,741 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 76 unique allowlist entries for `setuptools` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `setuptools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 872
    - Unannotated parameters: 239
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 13
- Returns:
    - Annotated returns: 719
    - Unannotated returns: 108
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 11
- Variables:
    - Annotated variables: 581
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 198
- Class definitions:
    - Total class definitions: 124
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `shapely`

### Upstream repo URL

[https://github.com/shapely/shapely](https://github.com/shapely/shapely)

### Stub distribution name

`types-shapely`

### Number of lines

2,803 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `shapely` when running stubtest in CI.

### Pyright settings in CI: *entirely excluded*

All files in this stubs package are excluded from the pyright check in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `shapely`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,524
    - Unannotated parameters: 426
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 737
    - Unannotated returns: 1
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 157
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `simplejson`

### Upstream repo URL

[https://github.com/simplejson/simplejson](https://github.com/simplejson/simplejson)

### Stub distribution name

`types-simplejson`

### Number of lines

292 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 10 unique allowlist entries for `simplejson` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `simplejson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 179
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 49
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `singledispatch`

### Upstream repo URL

[https://github.com/jaraco/singledispatch](https://github.com/jaraco/singledispatch)

### Stub distribution name

`types-singledispatch`

### Number of lines

28 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `singledispatch` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `singledispatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `six`

### Upstream repo URL

[https://github.com/benjaminp/six](https://github.com/benjaminp/six)

### Stub distribution name

`types-six`

### Number of lines

331 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 22 unique allowlist entries for `six` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `six`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 69
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `slumber`

### Upstream repo URL

[https://github.com/samgiles/slumber](https://github.com/samgiles/slumber)

### Stub distribution name

`types-slumber`

### Number of lines

74 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `slumber` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `slumber`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for the stdlib

### Upstream repo URL

[https://github.com/python/cpython](https://github.com/python/cpython)

### Number of lines

66,500 (excluding blank lines)

### Package status: *stdlib*

These are typeshed's stubs for the standard library. Typeshed's stdlib stubs are generally fairly up to date, and are tested against all currently supported Python versions in typeshed's CI.

### Upload status: *not currently uploaded*

These stubs are not currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 839 unique allowlist entries for the stdlib when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for the stdlib

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 29,368
    - Unannotated parameters: 633
    - Explicit `Any` parameters: 2,083
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 14
- Returns:
    - Annotated returns: 16,303
    - Unannotated returns: 271
    - Explicit `Any` returns: 832
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 9,284
    - Explicit `Any` variables: 308
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 235
- Class definitions:
    - Total class definitions: 3,146
    - Class definitions with `Any`: 26
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `str2bool`

### Upstream repo URL

[https://github.com/symonsoft/str2bool](https://github.com/symonsoft/str2bool)

### Stub distribution name

`types-str2bool`

### Number of lines

6 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `str2bool` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `str2bool`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tabulate`

### Upstream repo URL

[https://github.com/astanin/python-tabulate](https://github.com/astanin/python-tabulate)

### Stub distribution name

`types-tabulate`

### Number of lines

61 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `tabulate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tabulate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tensorflow`

### Extra description

Partially generated using [mypy-protobuf==3.6.0](https://github.com/nipunn1313/mypy-protobuf/tree/v3.6.0) and libprotoc 27.2 on `tensorflow==2.18.0`.

### Upstream repo URL

[https://github.com/tensorflow/tensorflow](https://github.com/tensorflow/tensorflow)

### Stub distribution name

`types-tensorflow`

### Number of lines

30,204 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 51 unique allowlist entries for `tensorflow` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `tensorflow`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5,345
    - Unannotated parameters: 36
    - Explicit `Any` parameters: 60
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 12
- Returns:
    - Annotated returns: 2,927
    - Unannotated returns: 39
    - Explicit `Any` returns: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 23
- Variables:
    - Annotated variables: 5,431
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 9
- Class definitions:
    - Total class definitions: 920
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `toml`

### Upstream repo URL

[https://github.com/uiri/toml](https://github.com/uiri/toml)

### Stub distribution name

`types-toml`

### Number of lines

136 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `toml` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `toml`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `toposort`

### Upstream repo URL

[https://gitlab.com/ericvsmith/toposort](https://gitlab.com/ericvsmith/toposort)

### Stub distribution name

`types-toposort`

### Number of lines

14 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `toposort` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `toposort`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tqdm`

### Upstream repo URL

[https://github.com/tqdm/tqdm](https://github.com/tqdm/tqdm)

### Stub distribution name

`types-tqdm`

### Number of lines

1,372 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `tqdm` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `tqdm`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 809
    - Unannotated parameters: 153
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 31
- Returns:
    - Annotated returns: 167
    - Unannotated returns: 27
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 105
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 76
- Class definitions:
    - Total class definitions: 36
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `translationstring`

### Upstream repo URL

[https://github.com/Pylons/translationstring](https://github.com/Pylons/translationstring)

### Stub distribution name

`types-translationstring`

### Number of lines

73 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `translationstring` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `translationstring`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 62
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ttkthemes`

### Upstream repo URL

[https://github.com/RedFantom/ttkthemes](https://github.com/RedFantom/ttkthemes)

### Stub distribution name

`types-ttkthemes`

### Number of lines

126 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ttkthemes` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ttkthemes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 79
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `uWSGI`

### Extra description

Type hints for uWSGI's [Python API](https://uwsgi-docs.readthedocs.io/en/latest/PythonModule.html). Note that this API is available only when running Python code inside a uWSGI process and some parts of the API are only present when corresponding configuration options have been enabled.

### Upstream repo URL

[https://github.com/unbit/uwsgi](https://github.com/unbit/uwsgi)

### Stub distribution name

`types-uWSGI`

### Number of lines

381 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 9 unique allowlist entries for `uWSGI` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `uWSGI`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 338
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 216
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 61
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ujson`

### Upstream repo URL

[https://github.com/ultrajson/ultrajson](https://github.com/ultrajson/ultrajson)

### Stub distribution name

`types-ujson`

### Number of lines

49 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ujson` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ujson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `unidiff`

### Upstream repo URL

[https://github.com/matiasb/python-unidiff](https://github.com/matiasb/python-unidiff)

### Stub distribution name

`types-unidiff`

### Number of lines

144 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `unidiff` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `unidiff`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 34
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 32
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `untangle`

### Upstream repo URL

[https://github.com/stchris/untangle](https://github.com/stchris/untangle)

### Stub distribution name

`types-untangle`

### Number of lines

33 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `untangle` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `untangle`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 21
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `usersettings`

### Upstream repo URL

[https://github.com/glvnst/usersettings](https://github.com/glvnst/usersettings)

### Stub distribution name

`types-usersettings`

### Number of lines

12 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `usersettings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `usersettings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 7
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `vobject`

### Upstream repo URL

[https://github.com/py-vobject/vobject](https://github.com/py-vobject/vobject)

### Stub distribution name

`types-vobject`

### Number of lines

515 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 unique allowlist entries for `vobject` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `vobject`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 88
    - Unannotated parameters: 203
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 76
    - Unannotated returns: 102
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 174
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 80
- Class definitions:
    - Total class definitions: 51
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `waitress`

### Upstream repo URL

[https://github.com/Pylons/waitress](https://github.com/Pylons/waitress)

### Stub distribution name

`types-waitress`

### Number of lines

639 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 2 unique allowlist entries for `waitress` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `waitress`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 196
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 198
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 244
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 38
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `watchpoints`

### Upstream repo URL

[https://github.com/gaogaotiantian/watchpoints](https://github.com/gaogaotiantian/watchpoints)

### Stub distribution name

`types-watchpoints`

### Number of lines

146 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `watchpoints` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `watchpoints`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 32
    - Explicit `Any` variables: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `whatthepatch`

### Upstream repo URL

[https://github.com/cscorley/whatthepatch](https://github.com/cscorley/whatthepatch)

### Stub distribution name

`types-whatthepatch`

### Number of lines

102 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `whatthepatch` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `whatthepatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 54
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `workalendar`

### Upstream repo URL

[https://github.com/workalendar/workalendar](https://github.com/workalendar/workalendar)

### Stub distribution name

`types-workalendar`

### Number of lines

3,248 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `workalendar` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `workalendar`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 21
    - Unannotated parameters: 422
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 22
    - Unannotated returns: 355
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 1,367
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 249
- Class definitions:
    - Total class definitions: 374
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `wurlitzer`

### Upstream repo URL

[https://github.com/minrk/wurlitzer](https://github.com/minrk/wurlitzer)

### Stub distribution name

`types-wurlitzer`

### Number of lines

130 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `wurlitzer` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `wurlitzer`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 95
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 32
    - Unannotated returns: 1
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xdgenvpy`

### Upstream repo URL

[https://gitlab.com/deliberist-group/xdgenvpy](https://gitlab.com/deliberist-group/xdgenvpy)

### Stub distribution name

`types-xdgenvpy`

### Number of lines

40 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `xdgenvpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xdgenvpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xlrd`

### Upstream repo URL

[https://github.com/python-excel/xlrd](https://github.com/python-excel/xlrd)

### Stub distribution name

`types-xlrd`

### Number of lines

765 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xlrd` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xlrd`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 299
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 143
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 426
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 33
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xmltodict`

### Upstream repo URL

[https://github.com/martinblech/xmltodict](https://github.com/martinblech/xmltodict)

### Stub distribution name

`types-xmltodict`

### Number of lines

35 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xmltodict` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xmltodict`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `zstd`

### Upstream repo URL

[https://github.com/sergey-dryabzhinsky/python-zstd](https://github.com/sergey-dryabzhinsky/python-zstd)

### Stub distribution name

`types-zstd`

### Number of lines

25 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `zstd` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `zstd`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 14
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `zxcvbn`

### Upstream repo URL

[https://github.com/dwolfhub/zxcvbn-python](https://github.com/dwolfhub/zxcvbn-python)

### Stub distribution name

`types-zxcvbn`

### Number of lines

164 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `zxcvbn` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `zxcvbn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 64
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 76
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

[stubtest]: https://mypy.readthedocs.io/en/stable/stubtest.html "A tool shipped with the mypy type checker for automatically verifying that stubs are consistent with the runtime package"
